"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Generator = require("yeoman-generator");
const path_1 = require("path");
module.exports = class extends Generator {
    initializing() {
        this.pkg = this.fs.readJSON(this.destinationPath('package.json'), {});
        if (this.pkg && Object.keys(this.pkg).length) {
            console.log('Found existing package.json:');
            console.log(this.pkg);
        }
    }
    writing() {
        [
            // Root
            '.gitignore',
            '.nycrc',
            '.prettierrc',
            'tsconfig.json',
            'tslint.json',
            'webpack.config.js',
            // Source
            path_1.join('src', 'custom.d.ts'),
            path_1.join('src', 'index.html'),
            path_1.join('src', 'index.less'),
            path_1.join('src', 'index.ts'),
        ].forEach(file => {
            this.fs.copy(this.templatePath(file + '.template'), this.destinationPath(file));
        });
        ['package.json', 'README.md'].forEach(file => {
            this.fs.copyTpl(this.templatePath(file + '.template'), this.destinationPath(file), {
                name: this.pkg.name || 'ts-website',
                version: this.pkg.version || '0.0.1',
                description: this.pkg.description ||
                    'Blank web application built with Typescript and LESS',
                author: this.pkg.author || '',
                license: this.pkg.license || 'ISC',
            });
        });
    }
    install() {
        this.npmInstall([
            '@types/chai',
            '@types/mocha',
            '@types/node',
            'chai',
            'css-hot-loader',
            'css-loader',
            'html-webpack-plugin',
            'less',
            'less-loader',
            'mini-css-extract-plugin',
            'mocha',
            'nyc',
            'prettier',
            'source-map-support',
            'ts-loader',
            'ts-node',
            'tslint',
            'typescript@3',
            'webpack@4',
            'webpack-cli',
            'webpack-dev-server',
            'webpack-merge',
        ], { 'save-dev': true });
    }
};
